import numpy
import math
import pylab
import matplotlib.pyplot as plt
import allantools as allan

# format:
# timestamp   frequency
def read_frequency_file(fname,col=1):
    f=[]
    t=[]
    with open(fname) as fid:
        for line in fid:
            if not line.startswith('#'): # skip comments
                l2 = line.split()
                tt = float(l2[0])
                ff = float(l2[col])
                f.append(ff)
                t.append(tt)
    assert( len(f) == len(t) )
    print "read ", len(f)," rows from file"
    print "mean ", numpy.mean(f), "max ", max(f)," min ", min(f)
    
    return (t,f)

(tc,fc) = read_frequency_file('2015-06-18_cont_refout.txt')
#th2 = [(x-tf2[0])/float(3600) for x in tf2]
fc_mu = numpy.mean(fc)
fc_fractional =[(x-fc_mu)/fc_mu for x in fc] 
rate=1.0
taus=numpy.logspace(0,3,20)
(taus_cont, devs_cont, ade, adn) = allan.oadev(fc_fractional, rate, taus)

(tr,fr) = read_frequency_file('2015-06-18_rcon_refout.txt')
fr_mu = numpy.mean(fr)
fr_fractional =[(x-fr_mu)/fr_mu for x in fr] 
rate=1.0
taus=numpy.logspace(0,3,20)
(taus_rcon, devs_rcon, ade, adn) = allan.oadev(fr_fractional, rate, taus)

plt.figure()
plt.loglog(taus_cont,devs_cont,'bo',label='CONT, 1s gate')
plt.loglog(taus_rcon,devs_rcon,'ro',label='RCON, 1s gate')
print devs_cont
print devs_rcon
plt.loglog( taus, [ 1.8e-11/x for x in taus],'k--',label="1.8e-11/tau, 1 PPS TIC noise floor")
plt.loglog( taus, [ devs_rcon[0]/x for x in taus],'r--',label="%.1g/tau" % devs_rcon[0])
plt.loglog( taus, [ devs_cont[0]/math.sqrt(x) for x in taus],'m--',label="%.1g/sqrt(tau)" % devs_cont[0])

#plt.xlim((0.9,1e3))
plt.grid()
plt.legend(framealpha=0.5)
plt.xlabel('Tau / s')
plt.ylabel('Allan deviation')
plt.title('CONT and RCON on 53230A, AW 2015-06-24')
plt.show()
